@@ -95,6 +95,7 @@ class DynamixelHelloXL430(Device):
             self.comm_errors = DynamixelCommErrorStats(name,logger=self.logger)
             self.v_des = None #Track the motion profile settings on servo
             self.a_des = None #Track the motion profile settings on servo
+            self.warn_error=False
         except KeyError:
             self.motor=None
 
@@ -159,6 +160,20 @@ class DynamixelHelloXL430(Device):
     def do_ping(self, verbose=False):
         return self.motor.do_ping(verbose)
 
+    def check_servo_errors(self):
+        if self.status['overload_error']:
+            msg = 'WARNING: Servo %s in error state: overload_error. Reboot servo with stretch_robot_dynamixel_reboot.py' % self.name
+            self.logger.warning(msg)
+            self.warn_error = True
+            return False
+
+        if self.status['overheating_error']:
+            msg = 'WARNING: Servo %s in error state: overheating_error. Reboot servo with stretch_robot_dynamixel_reboot.py' % self.name
+            self.logger.warning(msg)
+            self.warn_error=True
+            return False
+        return True
+
     def startup(self, threaded=False):
         if self.motor is None:
             return False
@@ -188,7 +203,16 @@ class DynamixelHelloXL430(Device):
                 self.is_calibrated=self.motor.is_calibrated()
                 self.check_homing_offset()
                 self.enable_torque()
+                #Pull 3 times given mux / init the status dict
                 self.pull_status()
+                self.pull_status()
+                self.pull_status()
+
+                if not self.check_servo_errors():
+
+                    self.hw_valid = False
+                    return False
+
                 return True
             else:
                 self.logger.warning('DynamixelHelloXL430 Ping failed... %s' % self.name)
@@ -261,6 +285,7 @@ class DynamixelHelloXL430(Device):
 
                 self.status_mux_id = (self.status_mux_id + 1) % 3
 
+                self.check_servo_errors()
 
                 if not pos_valid or not vel_valid or not eff_valid or not temp_valid or not err_valid:
                     raise DynamixelCommError
@@ -733,7 +758,8 @@ class DynamixelHelloXL430(Device):
             return False, None
 
         self.pull_status()
-        if self.status['overload_error'] or self.status['overheating_error']:
+
+        if not self.check_servo_errors():
             self.logger.warning('Hardware error, unable to home. Exiting')
             return False, None
 
@@ -753,7 +779,8 @@ class DynamixelHelloXL430(Device):
         if timeout:
             self.logger.warning('Timed out moving to first hardstop. Exiting.')
             return False, None
-        if self.status['overload_error'] or self.status['overheating_error']:
+
+        if not self.check_servo_errors():
             self.logger.warning('Hardware error, unable to home. Exiting')
             return False, None
 
@@ -798,7 +825,8 @@ class DynamixelHelloXL430(Device):
             if timeout:
                 self.logger.warning('Timed out moving to second hardstop. Exiting.')
                 return False, None
-            if self.status['overload_error'] or self.status['overheating_error']:
+
+            if not self.check_servo_errors():
                 self.logger.warning('Hardware error, unable to home. Exiting')
                 return False, None
 
