@@ -11,6 +11,106 @@ from concurrent.futures import ThreadPoolExecutor
 
 class TestDynamixelXL430(unittest.TestCase):
 
+    def test_set_get_float(self):
+        """
+        Verify that passing floats to API doesn't crash and that can set/get values consistently
+        """
+        print('Testing Set Get Float')
+        usb = "/dev/hello-dynamixel-head"
+        dxl_id = 12
+        baud = stretch_body.dynamixel_XL430.DynamixelXL430.identify_baud_rate(dxl_id, usb)
+        m = stretch_body.dynamixel_XL430.DynamixelXL430(dxl_id,usb, baud=baud)
+        self.assertTrue(m.startup())
+        x=m.is_calibrated()
+        m.set_calibrated(float(x))
+        self.assertEqual(m.is_calibrated(), x)
+
+        x = m.get_return_delay_time()
+        m.set_return_delay_time(float(x))
+        self.assertEqual(m.get_return_delay_time(), x)
+
+        x = m.get_pwm()
+        m.set_pwm(float(x))
+        self.assertEqual(m.get_pwm(), x)
+
+        x = m.get_current_limit()
+        m.set_current_limit(float(x))
+        self.assertEqual(m.get_current_limit(), x)
+
+        x = m.get_goal_current()
+        m.set_goal_current(float(x))
+        self.assertEqual(m.get_goal_current(), x)
+
+        x = m.get_pos()
+        m.go_to_pos(float(x))
+        self.assertEqual(m.get_pos(), x)
+
+        x = m.get_vel()
+        m.set_vel(float(x))
+        self.assertEqual(m.get_vel(), x)
+
+        x = m.get_profile_velocity()
+        m.set_profile_velocity(float(x))
+        self.assertEqual(m.get_profile_velocity(), x)
+
+        x = m.get_profile_acceleration()
+        m.set_profile_acceleration(float(x))
+        self.assertEqual(m.get_profile_acceleration(), x)
+
+        x = m.get_P_gain()
+        m.set_P_gain(float(x))
+        self.assertEqual(m.get_P_gain(), x)
+
+        x = m.get_I_gain()
+        m.set_I_gain(float(x))
+        self.assertEqual(m.get_I_gain(), x)
+
+        x = m.get_D_gain()
+        m.set_D_gain(float(x))
+        self.assertEqual(m.get_D_gain(), x)
+
+        x = m.get_temperature_limit()
+        m.set_temperature_limit(float(x))
+        self.assertEqual(m.get_temperature_limit(), x)
+
+        x = m.get_temperature_limit()
+        m.set_temperature_limit(float(x))
+        self.assertEqual(m.get_temperature_limit(), x)
+
+        x = m.get_max_voltage_limit()
+        m.set_max_voltage_limit(float(x))
+        self.assertEqual(m.get_max_voltage_limit(), x)
+
+        x = m.get_min_voltage_limit()
+        m.set_min_voltage_limit(float(x))
+        self.assertEqual(m.get_min_voltage_limit(), x)
+
+        x = m.get_vel_limit()
+        m.set_vel_limit(float(x))
+        self.assertEqual(m.get_vel_limit(), x)
+
+        x = m.get_max_pos_limit()
+        m.set_max_pos_limit(float(x))
+        self.assertEqual(m.get_max_pos_limit(), x)
+
+        x = m.get_min_pos_limit()
+        m.set_min_pos_limit(float(x))
+        self.assertEqual(m.get_min_pos_limit(), x)
+
+        x = m.get_moving_threshold()
+        m.set_moving_threshold(float(x))
+        self.assertEqual(m.get_moving_threshold(), x)
+
+        x = m.get_pwm_limit()
+        m.set_pwm_limit(float(x))
+        self.assertEqual(m.get_pwm_limit(), x)
+
+        x = m.get_homing_offset()
+        m.set_homing_offset(float(x))
+        self.assertEqual(m.get_homing_offset(), x)
+
+        m.stop()
+
     def test_concurrent_access(self):
         """Verify zero comms errors in concurrent access.
         """
